.. image:: https://travis-ci.org/ome/omero-upload.svg?branch=master
    :target: https://travis-ci.org/ome/omero-upload

.. image:: https://badge.fury.io/py/omero-upload.svg
    :target: https://badge.fury.io/py/omero-upload

OMERO CLI upload
================

Plugin for uploading files using the OMERO Command Line Interface (CLI).

Requirements
============

* OMERO 5.4.0 or newer
* Python 2.7

Installing from PyPI
====================

This section assumes that an OMERO.py is already installed.

Install the command-line tool using `pip <https://pip.pypa.io/en/stable/>`_::

    $ pip install -U omero-upload

License
-------

This project, similar to many Open Microscopy Environment (OME) projects, is
licensed under the terms of the GNU General Public License (GPL) v2 or later.

Copyright
---------

2019, The Open Microscopy Environment
